/**
 * Parse object to query params
 * @param {object} obj
 * @returns {string}
 */
export function objectToQueryString (obj) {
  return Object.keys(obj || {})
    .filter(key => (((obj[key] !== '') && (obj[key] !== null))))
    .map((key) => {
      const value = (typeof obj[key] === 'function')
        ? encodeURIComponent(obj[key]())
        : encodeURIComponent(obj[key])

      return `${key}=${value}`
    })
    .join('&')
}

/**
 * Append query params to url
 * @param {string} url
 * @param {string} queryString
 * @returns {string}
 */
export function appendQueryStringToURL (url, queryString) {
  const mark = (queryString) ? (((url || '').indexOf('?') === -1) ? '?' : '&') : ''

  return `${url}${mark}${queryString}`
}
